let markdownItContainer = window.markdownitContainer
const md = window.markdownit({
	html: true,
	highlight: (str, lang) => {
		if (lang && hljs.getLanguage(lang)) {
			try {
				return hljs.highlight(lang, str).value
			} catch (_) {

			}
		}
		return ""
	}
}).use(window.markdownItKatex, { throwOnError: false, errorColor: '#cc0000' })
	.use(markdownItContainer, 'warning', {
		validate: function (params) {
			return params.trim() === 'warning'
		},
		render: (tokens, idx) => {
			if (tokens[idx].nesting === 1) {
				const icon = `<i class="markdown-it-alert-icon markdown-it-alert-icon-warning"><svg viewBox="64 64 896 896" data-icon="exclamation-circle" width="1em" height="1em" fill="currentColor" aria-hidden="true" class=""><path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm-32 232c0-4.4 3.6-8 8-8h48c4.4 0 8 3.6 8 8v272c0 4.4-3.6 8-8 8h-48c-4.4 0-8-3.6-8-8V296zm32 440a48.01 48.01 0 0 1 0-96 48.01 48.01 0 0 1 0 96z"></path></svg></i>`
				return `<div class="markdown-it-alter markdown-it-alter-warning">${icon}`
			} else {
				return '</div>'
			}
		}
	})
	.use(markdownItContainer, 'info', {
		validate: function (params) {
			return params.trim() === 'info'
		},
		render: (tokens, idx) => {
			if (tokens[idx].nesting === 1) {
				const icon = `<i class="markdown-it-alert-icon markdown-it-alert-icon-info"><svg viewBox="64 64 896 896" data-icon="info-circle" width="1em" height="1em" fill="currentColor" aria-hidden="true" class=""><path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm32 664c0 4.4-3.6 8-8 8h-48c-4.4 0-8-3.6-8-8V456c0-4.4 3.6-8 8-8h48c4.4 0 8 3.6 8 8v272zm-32-344a48.01 48.01 0 0 1 0-96 48.01 48.01 0 0 1 0 96z"></path></svg></i>`
				return `<div class="markdown-it-alter markdown-it-alter-info">${icon}`
			} else {
				return '</div>'
			}
		}
	})
	.use(markdownItContainer, 'success', {
		validate: function (params) {
			return params.trim() === 'success'
		},
		render: (tokens, idx) => {
			if (tokens[idx].nesting === 1) {
				const icon = `<i class="markdown-it-alert-icon markdown-it-alert-icon-success"><svg viewBox="64 64 896 896" data-icon="check-circle" width="1em" height="1em" fill="currentColor" aria-hidden="true" class=""><path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm193.5 301.7l-210.6 292a31.8 31.8 0 0 1-51.7 0L318.5 484.9c-3.8-5.3 0-12.7 6.5-12.7h46.9c10.2 0 19.9 4.9 25.9 13.3l71.2 98.8 157.2-218c6-8.3 15.6-13.3 25.9-13.3H699c6.5 0 10.3 7.4 6.5 12.7z"></path></svg></i>`
				return `<div class="markdown-it-alter markdown-it-alter-success">${icon}`
			} else {
				return '</div>'
			}
		}
	})
	.use(markdownItContainer, 'error', {
		validate: function (params) {
			return params.trim() === 'error'
		},
		render: (tokens, idx) => {
			if (tokens[idx].nesting === 1) {
				const icon = `<i class="markdown-it-alert-icon markdown-it-alert-icon-error"><svg viewBox="64 64 896 896" data-icon="close-circle" width="1em" height="1em" fill="currentColor" aria-hidden="true" class=""><path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm165.4 618.2l-66-.3L512 563.4l-99.3 118.4-66.1.3c-4.4 0-8-3.5-8-8 0-1.9.7-3.7 1.9-5.2l130.1-155L340.5 359a8.32 8.32 0 0 1-1.9-5.2c0-4.4 3.6-8 8-8l66.1.3L512 464.6l99.3-118.4 66-.3c4.4 0 8 3.5 8 8 0 1.9-.7 3.7-1.9 5.2L553.5 514l130 155c1.2 1.5 1.9 3.3 1.9 5.2 0 4.4-3.6 8-8 8z"></path></svg></i>`
				return `<div class="markdown-it-alter markdown-it-alter-error">${icon}`
			} else {
				return '</div>'
			}
		}
	})

function setContent(content) {
	document.getElementById("content").innerHTML = md.render(content)
}

function useDarkTheme() {
	const container = document.getElementById("container")
	if (!container.classList.contains("dark")) {
	    document.body.style.backgroundColor = "#212a33"
		container.classList.add("dark")
	}
	var elements = document.querySelectorAll('.dark.container');
            elements.forEach(function(el) {
              el.style.backgroundColor = '#212a33';
            });
}

function useLightTheme() {
    const container = document.getElementById("container")
    if (container.classList.contains("dark")) {
    	document.body.style.backgroundColor = "#FFFFFF"
        container.classList.remove("dark")
    }
    var elements = document.querySelectorAll('.container');
       elements.forEach(function(el) {
         el.style.backgroundColor = '#FFFFFF';
       });
}

function useFastDarkTheme() {
	const container = document.getElementById("container")
	if (!container.classList.contains("dark")) {
	    document.body.style.backgroundColor = "#1C232B"
		container.classList.add("dark")
	}
	var elements = document.querySelectorAll('.dark.container');
        elements.forEach(function(el) {
          el.style.backgroundColor = '#1C232B';
        });
}

function useFastLightTheme() {
    const container = document.getElementById("container")
    if (container.classList.contains("dark")) {
    	document.body.style.backgroundColor = "#F8F8F8"
        container.classList.remove("dark")
    }
    var elements = document.querySelectorAll('.container');
    elements.forEach(function(el) {
      el.style.backgroundColor = '#F8F8F8';
    });
}